======
Basics
======

This section will cover the basic ideas behind this package.
We introduce the Fused Unbalanced Gromov Wasserstein loss and
its dense solvers. Then we show how a large, low-rank geometry
can be approximated with by computing an embedding, resulting in
much less memory usage. Finally, we show how these embeddings
can be used in combination with sparse solvers for the FUGW loss.